This function performance the GIBBS sampler for analyze reginals trials.
RGEgibbs(data, gen_c, env_c, blk_c, y_c, prior.g = NULL,
prior.vg =NULL,prior.b = NULL, prior.dfb = NULL,
prior.sv = NULL, prior.dfsv = NULL, prior.se = NULL,
prior.dfse = NULL,
burnin = 10, thin = 5, niter = 50, saveAt = 10)data.frame
Number of the column from de data.frame with the genotypes information.
Number of the column from de data.frame with the environment information.
Number of the column from de data.frame with the block information.
Number of the column from de data.frame with the phenotype information.
Vector with prior information of the means of genotypes
Vector with prior information of the variances of the means of genotypes
Vector with prior information of the variances of block within environment
Vector with prior information of hyperparameter degree of credibility of the variances of block within environment.
Vector with prior information of the stability's variances
Vector with prior information of hyperparameter degree of credibility of the stability's variances.
Vector with prior information of the error's variances
Vector with prior information of hyperparameter degree of credibility of the variances of error.
Number of iteration to be consider as burn-in period. This period is not saved in the final result.
The thinning interval between consecutive observations. This interval is not saved in the final result.
Numbers of iterations to be saved
Save object outtS4 with samples of the posterior distribution on the work directory each "saveAt" iteration
Matrix with samples of the posterior distribution
Cotes Torres, J. M., Gonzalez Jaimes, E. P., & Cotes Torres, A. (2016). Seleccion de Genotipos con Alta Respuesta y Estabilidad Fenotipica en Pruebas Regionales: Recuperando el Concepto Biologico. Revista Facultad De Ciencias Basicas, 8(2), 226-243.
# NOT RUN {
##data(datos)
##m<-RGEgibbs(data=datos,gen_c=5,env_c=1,blk_c=4,y_c=9,
##thin=5,burnin=100,niter=10000,saveAt=1000)
# }
Run the code above in your browser using DataLab